﻿using System;
using System.Globalization;

using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 일자 카운트
        /// </summary>
        private int dateCount = 0;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                true,                          // Multi Select
                GridMultiSelectMode.RowSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,  // Draw Focus Rect Style
                true,                          // Show Indicator
                true,                          // Show Column Headers
                true,                          // Allow Column Moving
                true,                          // Allow Column Resizing
                true,                          // Allow Filter
                true,                          // Allow Sort
                false,                         // Allow Cell Merge
                EditorShowMode.Default,        // Editor Show Mode
                false                          // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsBehavior.AutoExpandAllGroups = true;

            this.gridView.OptionsView.ShowGroupPanel = true;

            this.gridView.OptionsView.ShowGroupedColumns = true;

            this.gridView.CustomSummaryCalculate += gridView_CustomSummaryCalculate;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.OrdersTableAdapter().GetData();

            this.gridView.Columns["OrderDate"].GroupIndex = 0;

            this.gridView.GroupSummary.Add(SummaryItemType.Custom, "OrderDate", gridView.Columns["OrderDate"], "{0} this week");

            this.gridView.BestFitColumns();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 SUMMARY 커스텀 계산하기 - gridView_CustomSummaryCalculate(sender, e)

        /// <summary>
        /// 그리드 뷰 SUMMARY 커스텀 계산하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_CustomSummaryCalculate(object sender, CustomSummaryEventArgs e)
        {
            if(e.IsGroupSummary)
            {
                GridView gridView = sender as GridView;

                switch(e.SummaryProcess)
                {
                    case CustomSummaryProcess.Start :

                        dateCount = 0;

                        break;

                    case CustomSummaryProcess.Calculate :

                        DateTime orderDate = Convert.ToDateTime(gridView.GetRowCellValue(e.RowHandle, gridView.Columns["OrderDate"]));

                        DateTime currentDate = DateTime.Now;

                        CultureInfo cultureInfo = CultureInfo.CurrentCulture;

                        int orderDateWeek = cultureInfo.Calendar.GetWeekOfYear
                        (
                            orderDate,
                            CalendarWeekRule.FirstDay,
                            DayOfWeek.Monday
                        );

                        int currentDateWeek = cultureInfo.Calendar.GetWeekOfYear
                        (
                            currentDate,
                            CalendarWeekRule.FirstDay,
                            DayOfWeek.Monday
                        );

                        if(orderDateWeek == currentDateWeek)
                        {
                            dateCount++;
                        }

                        break;

                        case CustomSummaryProcess.Finalize :

                            e.TotalValue = dateCount;

                            break;
                }
            }
        }

        #endregion
    }
}